# CoVERT Dataset

## Introduction

This README file describes the CoVERT dataset created for fact-checking 
biomedical COVID-19 tweets. It consists of 300 tweets annotated with entities,
each fact-checked by crowdsourced annotators. Each tweet has three annotations
consisting of a fact-checking verdict (or label), a URL link to substantiating
evidence and a textual evidence snippet.

The files in this directory belong to the paper:

Isabelle Mohr, Amelie Wuehrl, Roman Klinger:
"CoVERT: A Corpus of Crowdsourced Fact-checking Verdicts for Biomedical
COVID-19 Tweets"

Please cite this paper as:

```
@InProceedings{mohr_wuehrl_klinger_2022,
  author    = {Mohr, Isabelle  and  Wuehrl, Amelie  and  Klinger, Roman},
  title     = {CoVERT: A Corpus of Crowdsourced Fact-checking Verdicts for Biomedical
COVID-19 Tweets},
  booktitle      = {Proceedings of The 13th Language Resources and Evaluation Conference},
  month          = {June},
  year           = {2022},
  address        = {Marseille, France},
  publisher      = {European Language Resources Association}
}
```

Any questions regarding the data should be directed to
Isabelle Mohr at: isabelle.mohr@ims.uni-stuttgart.de

## Content

This directory (`/data`) contains two files, namely

* `CoVERT_biomed_entity_annotations.csv`		        : biomedical entity annotations
* `CoVERT_FC_annotations.jsonl`	: tweets and fact-checking responses by crowdsourced annotators
* `annotation_guidelines.pdf`   : the annotation guidelines

## Data Format

**a. CoVERT_biomed_entity_annotations.csv**

The biomedical named entities relating to COVID-19 claims are annotated per 
tweet. See the example instance below.

    ID,token,start,end,label,XY,R
    1234,COVID-19,0,7,Medical Condition,Y,UR214

The first column of the .csv file contains the unique tweet ID for the 
annotation, the second column contains the token(s) being annotated, followed 
by two columns that contain the start and end character positions of the entity 
respectively. The next column contains an entity label from the following list:

* Treatment             : any medical care given to a patient for a disease or 
                          illness 
* Symptom/Side-effect   : a secondary physical effect of a medical treatment or 
                          medical condition
* Medical Condition     : any disease, illness, ailment or disorder
* Other                 : any other entity that does not fall into the above 
                          mentioned categories but is still relevant to the 
                          claim phrase

The penultimate column states the grammatical function of the entity, which is
either Y for subject or X for object. Lastly, the predicate relation between
the entities is noted in the last column, taken from the following list:

* UR214 : cause_of
* UR173 : causative_agent_of
* UR214!: not_cause_of

**b. CoVERT_FC_annotations.jsonl**

The .jsonl file consists of 300 lines where each line contains the
annotations for one tweet in json format. Each tweet has been anonymised,
replacing all twitter handles with `@username`. Each tweet has three annotations,
captured in the "evidence" field. The format is as follows:

    {"id"       :   hashID for the tweet,
     "claim"    :   original tweet,
     "evidence" :   [
                    [label, URL link, textual evidence, annotator ID],
                    [...],
                    [...]
                    ]
    "label":    :   majority label from the three annotations
    }

Labels can be any of the following:

- SUPPORTS
- REFUTES
- Not Enough Information (NEI)

## License

We publish the annotations of this dataset under the CC BY SA license. The
tweets contained in this dataset are shared in line with Twitter's terms and
conditions due to its limited size of 300 tweets. For more information on 
Twitter's terms and conditions, please refer to their [policy](https://developer.twitter.com/en/developer-terms/agreement-and-policy).
